@@ -2,7 +2,7 @@ import _ from 'lodash'
 import React from 'react'
 import { Link } from 'react-router-dom'
 import moment from 'moment'
-import { AcmLabels } from '@open-cluster-management/ui-components'
+import { AcmLabels } from '@stolostron/ui-components'
 
 // eslint-disable-next-line import/no-anonymous-default-export
 const searchDefinitions: any = {
@@ -1385,7 +1385,7 @@ export function CreateDashboardLink(item: any) {
     if (item.dashboard !== null && item.dashboard !== '') {
         return (
             <a target="_blank" rel="noopener noreferrer" href={item.dashboard}>
-                {/* TODO Not translating - caused issue: https://github.com/open-cluster-management/backlog/issues/9184 */}
+                {/* TODO Not translating - caused issue: https://github.com/stolostron/backlog/issues/9184 */}
                 {'Launch health view'}
             </a>
         )
@@ -1397,7 +1397,7 @@ export function CreateExternalLink(item: any) {
     if (item.consoleURL) {
         return (
             <a target="_blank" rel="noopener noreferrer" href={`${item.consoleURL}`}>
-                {/* TODO Not translating - caused issue: https://github.com/open-cluster-management/backlog/issues/9184 */}
+                {/* TODO Not translating - caused issue: https://github.com/stolostron/backlog/issues/9184 */}
                 {'Launch'}
             </a>
         )
